@@ -41,6 +41,7 @@ constant(const char *name)
             if (strEQ(name, "GLOBAL_WIN32")) return CURL_GLOBAL_WIN32;
             break;
         case 'H':
+            if (strEQ(name, "HET_DEFAULT")) return CURL_HET_DEFAULT;
             if (strEQ(name, "HTTPPOST_BUFFER")) return CURL_HTTPPOST_BUFFER;
             if (strEQ(name, "HTTPPOST_CALLBACK")) return CURL_HTTPPOST_CALLBACK;
             if (strEQ(name, "HTTPPOST_FILENAME")) return CURL_HTTPPOST_FILENAME;
@@ -55,6 +56,7 @@ constant(const char *name)
             if (strEQ(name, "HTTP_VERSION_2TLS")) return CURL_HTTP_VERSION_2TLS;
             if (strEQ(name, "HTTP_VERSION_2_0")) return CURL_HTTP_VERSION_2_0;
             if (strEQ(name, "HTTP_VERSION_2_PRIOR_KNOWLEDGE")) return CURL_HTTP_VERSION_2_PRIOR_KNOWLEDGE;
+            if (strEQ(name, "HTTP_VERSION_3")) return CURL_HTTP_VERSION_3;
             if (strEQ(name, "HTTP_VERSION_NONE")) return CURL_HTTP_VERSION_NONE;
             break;
         case 'I':
@@ -72,6 +74,7 @@ constant(const char *name)
             if (strEQ(name, "LOCK_DATA_COOKIE")) return CURL_LOCK_DATA_COOKIE;
             if (strEQ(name, "LOCK_DATA_DNS")) return CURL_LOCK_DATA_DNS;
             if (strEQ(name, "LOCK_DATA_NONE")) return CURL_LOCK_DATA_NONE;
+            if (strEQ(name, "LOCK_DATA_PSL")) return CURL_LOCK_DATA_PSL;
             if (strEQ(name, "LOCK_DATA_SHARE")) return CURL_LOCK_DATA_SHARE;
             if (strEQ(name, "LOCK_DATA_SSL_SESSION")) return CURL_LOCK_DATA_SSL_SESSION;
             break;
@@ -139,16 +142,23 @@ constant(const char *name)
             if (strEQ(name, "TIMECOND_NONE")) return CURL_TIMECOND_NONE;
             if (strEQ(name, "TLSAUTH_NONE")) return CURL_TLSAUTH_NONE;
             if (strEQ(name, "TLSAUTH_SRP")) return CURL_TLSAUTH_SRP;
+            if (strEQ(name, "TRAILERFUNC_ABORT")) return CURL_TRAILERFUNC_ABORT;
+            if (strEQ(name, "TRAILERFUNC_OK")) return CURL_TRAILERFUNC_OK;
             break;
         case 'U':
+            if (strEQ(name, "UPKEEP_INTERVAL_DEFAULT")) return CURL_UPKEEP_INTERVAL_DEFAULT;
+            break;
         case 'V':
+            if (strEQ(name, "VERSION_ALTSVC")) return CURL_VERSION_ALTSVC;
             if (strEQ(name, "VERSION_ASYNCHDNS")) return CURL_VERSION_ASYNCHDNS;
+            if (strEQ(name, "VERSION_BROTLI")) return CURL_VERSION_BROTLI;
             if (strEQ(name, "VERSION_CONV")) return CURL_VERSION_CONV;
             if (strEQ(name, "VERSION_CURLDEBUG")) return CURL_VERSION_CURLDEBUG;
             if (strEQ(name, "VERSION_DEBUG")) return CURL_VERSION_DEBUG;
             if (strEQ(name, "VERSION_GSSAPI")) return CURL_VERSION_GSSAPI;
             if (strEQ(name, "VERSION_GSSNEGOTIATE")) return CURL_VERSION_GSSNEGOTIATE;
             if (strEQ(name, "VERSION_HTTP2")) return CURL_VERSION_HTTP2;
+            if (strEQ(name, "VERSION_HTTP3")) return CURL_VERSION_HTTP3;
             if (strEQ(name, "VERSION_HTTPS_PROXY")) return CURL_VERSION_HTTPS_PROXY;
             if (strEQ(name, "VERSION_IDN")) return CURL_VERSION_IDN;
             if (strEQ(name, "VERSION_IPV6")) return CURL_VERSION_IPV6;
@@ -156,6 +166,7 @@ constant(const char *name)
             if (strEQ(name, "VERSION_KERBEROS5")) return CURL_VERSION_KERBEROS5;
             if (strEQ(name, "VERSION_LARGEFILE")) return CURL_VERSION_LARGEFILE;
             if (strEQ(name, "VERSION_LIBZ")) return CURL_VERSION_LIBZ;
+            if (strEQ(name, "VERSION_MULTI_SSL")) return CURL_VERSION_MULTI_SSL;
             if (strEQ(name, "VERSION_NTLM")) return CURL_VERSION_NTLM;
             if (strEQ(name, "VERSION_NTLM_WB")) return CURL_VERSION_NTLM_WB;
             if (strEQ(name, "VERSION_PSL")) return CURL_VERSION_PSL;
@@ -171,6 +182,7 @@ constant(const char *name)
         case 'X':
         case 'Y':
         case 'Z':
+            if (strEQ(name, "ZERO_TERMINATED")) return CURL_ZERO_TERMINATED;
             break;
     };
     }
@@ -184,6 +196,7 @@ constant(const char *name)
         case 'D':
         case 'E':
         case 'F':
+            if (strEQ(name, "FIFTH")) return CURLVERSION_FIFTH;
             if (strEQ(name, "FIRST")) return CURLVERSION_FIRST;
             if (strEQ(name, "FOURTH")) return CURLVERSION_FOURTH;
             break;
@@ -203,6 +216,7 @@ constant(const char *name)
         case 'R':
         case 'S':
             if (strEQ(name, "SECOND")) return CURLVERSION_SECOND;
+            if (strEQ(name, "SIXTH")) return CURLVERSION_SIXTH;
             break;
         case 'T':
             if (strEQ(name, "THIRD")) return CURLVERSION_THIRD;
@@ -258,6 +272,154 @@ constant(const char *name)
     };
     }
 
+    if (strncmp(name, "CURLUPART_", 10) == 0) {
+        name += 10;
+        switch (*name) {
+        case 'A':
+        case 'B':
+        case 'C':
+        case 'D':
+        case 'E':
+        case 'F':
+            if (strEQ(name, "FRAGMENT")) return CURLUPART_FRAGMENT;
+            break;
+        case 'G':
+        case 'H':
+            if (strEQ(name, "HOST")) return CURLUPART_HOST;
+            break;
+        case 'I':
+        case 'J':
+        case 'K':
+        case 'L':
+        case 'M':
+        case 'N':
+        case 'O':
+            if (strEQ(name, "OPTIONS")) return CURLUPART_OPTIONS;
+            break;
+        case 'P':
+            if (strEQ(name, "PASSWORD")) return CURLUPART_PASSWORD;
+            if (strEQ(name, "PATH")) return CURLUPART_PATH;
+            if (strEQ(name, "PORT")) return CURLUPART_PORT;
+            break;
+        case 'Q':
+            if (strEQ(name, "QUERY")) return CURLUPART_QUERY;
+            break;
+        case 'R':
+        case 'S':
+            if (strEQ(name, "SCHEME")) return CURLUPART_SCHEME;
+            break;
+        case 'T':
+        case 'U':
+            if (strEQ(name, "URL")) return CURLUPART_URL;
+            if (strEQ(name, "USER")) return CURLUPART_USER;
+            break;
+        case 'V':
+        case 'W':
+        case 'X':
+        case 'Y':
+        case 'Z':
+            if (strEQ(name, "ZONEID")) return CURLUPART_ZONEID;
+            break;
+    };
+    }
+
+    if (strncmp(name, "CURLUE_", 7) == 0) {
+        name += 7;
+        switch (*name) {
+        case 'A':
+        case 'B':
+            if (strEQ(name, "BAD_HANDLE")) return CURLUE_BAD_HANDLE;
+            if (strEQ(name, "BAD_PARTPOINTER")) return CURLUE_BAD_PARTPOINTER;
+            if (strEQ(name, "BAD_PORT_NUMBER")) return CURLUE_BAD_PORT_NUMBER;
+            break;
+        case 'C':
+        case 'D':
+        case 'E':
+        case 'F':
+        case 'G':
+        case 'H':
+        case 'I':
+        case 'J':
+        case 'K':
+        case 'L':
+        case 'M':
+            if (strEQ(name, "MALFORMED_INPUT")) return CURLUE_MALFORMED_INPUT;
+            break;
+        case 'N':
+            if (strEQ(name, "NO_FRAGMENT")) return CURLUE_NO_FRAGMENT;
+            if (strEQ(name, "NO_HOST")) return CURLUE_NO_HOST;
+            if (strEQ(name, "NO_OPTIONS")) return CURLUE_NO_OPTIONS;
+            if (strEQ(name, "NO_PASSWORD")) return CURLUE_NO_PASSWORD;
+            if (strEQ(name, "NO_PORT")) return CURLUE_NO_PORT;
+            if (strEQ(name, "NO_QUERY")) return CURLUE_NO_QUERY;
+            if (strEQ(name, "NO_SCHEME")) return CURLUE_NO_SCHEME;
+            if (strEQ(name, "NO_USER")) return CURLUE_NO_USER;
+            break;
+        case 'O':
+            if (strEQ(name, "OK")) return CURLUE_OK;
+            if (strEQ(name, "OUT_OF_MEMORY")) return CURLUE_OUT_OF_MEMORY;
+            break;
+        case 'P':
+        case 'Q':
+        case 'R':
+        case 'S':
+        case 'T':
+        case 'U':
+            if (strEQ(name, "UNKNOWN_PART")) return CURLUE_UNKNOWN_PART;
+            if (strEQ(name, "UNSUPPORTED_SCHEME")) return CURLUE_UNSUPPORTED_SCHEME;
+            if (strEQ(name, "URLDECODE")) return CURLUE_URLDECODE;
+            if (strEQ(name, "USER_NOT_ALLOWED")) return CURLUE_USER_NOT_ALLOWED;
+            break;
+        case 'V':
+        case 'W':
+        case 'X':
+        case 'Y':
+        case 'Z':
+            break;
+    };
+    }
+
+    if (strncmp(name, "CURLSSLSET_", 11) == 0) {
+        name += 11;
+        switch (*name) {
+        case 'A':
+        case 'B':
+        case 'C':
+        case 'D':
+        case 'E':
+        case 'F':
+        case 'G':
+        case 'H':
+        case 'I':
+        case 'J':
+        case 'K':
+        case 'L':
+        case 'M':
+        case 'N':
+            if (strEQ(name, "NO_BACKENDS")) return CURLSSLSET_NO_BACKENDS;
+            break;
+        case 'O':
+            if (strEQ(name, "OK")) return CURLSSLSET_OK;
+            break;
+        case 'P':
+        case 'Q':
+        case 'R':
+        case 'S':
+        case 'T':
+            if (strEQ(name, "TOO_LATE")) return CURLSSLSET_TOO_LATE;
+            break;
+        case 'U':
+            if (strEQ(name, "UNKNOWN_BACKEND")) return CURLSSLSET_UNKNOWN_BACKEND;
+            break;
+        case 'V':
+        case 'W':
+        case 'X':
+        case 'Y':
+        case 'Z':
+            break;
+    };
+    }
+
     if (strncmp(name, "CURLSSLOPT_", 11) == 0) {
         name += 11;
         switch (*name) {
@@ -325,6 +487,7 @@ constant(const char *name)
             break;
         case 'M':
             if (strEQ(name, "MBEDTLS")) return CURLSSLBACKEND_MBEDTLS;
+            if (strEQ(name, "MESALINK")) return CURLSSLBACKEND_MESALINK;
             break;
         case 'N':
             if (strEQ(name, "NONE")) return CURLSSLBACKEND_NONE;
@@ -340,6 +503,7 @@ constant(const char *name)
         case 'R':
         case 'S':
             if (strEQ(name, "SCHANNEL")) return CURLSSLBACKEND_SCHANNEL;
+            if (strEQ(name, "SECURETRANSPORT")) return CURLSSLBACKEND_SECURETRANSPORT;
             break;
         case 'T':
         case 'U':
@@ -361,6 +525,7 @@ constant(const char *name)
             if (strEQ(name, "AUTH_AGENT")) return CURLSSH_AUTH_AGENT;
             if (strEQ(name, "AUTH_ANY")) return CURLSSH_AUTH_ANY;
             if (strEQ(name, "AUTH_DEFAULT")) return CURLSSH_AUTH_DEFAULT;
+            if (strEQ(name, "AUTH_GSSAPI")) return CURLSSH_AUTH_GSSAPI;
             if (strEQ(name, "AUTH_HOST")) return CURLSSH_AUTH_HOST;
             if (strEQ(name, "AUTH_KEYBOARD")) return CURLSSH_AUTH_KEYBOARD;
             if (strEQ(name, "AUTH_NONE")) return CURLSSH_AUTH_NONE;
@@ -685,6 +850,8 @@ constant(const char *name)
             if (strEQ(name, "ACCEPTTIMEOUT_MS")) return CURLOPT_ACCEPTTIMEOUT_MS;
             if (strEQ(name, "ACCEPT_ENCODING")) return CURLOPT_ACCEPT_ENCODING;
             if (strEQ(name, "ADDRESS_SCOPE")) return CURLOPT_ADDRESS_SCOPE;
+            if (strEQ(name, "ALTSVC")) return CURLOPT_ALTSVC;
+            if (strEQ(name, "ALTSVC_CTRL")) return CURLOPT_ALTSVC_CTRL;
             if (strEQ(name, "APPEND")) return CURLOPT_APPEND;
             if (strEQ(name, "AUTOREFERER")) return CURLOPT_AUTOREFERER;
             break;
@@ -716,6 +883,7 @@ constant(const char *name)
             if (strEQ(name, "COPYPOSTFIELDS")) return CURLOPT_COPYPOSTFIELDS;
             if (strEQ(name, "CRLF")) return CURLOPT_CRLF;
             if (strEQ(name, "CRLFILE")) return CURLOPT_CRLFILE;
+            if (strEQ(name, "CURLU")) return CURLOPT_CURLU;
             if (strEQ(name, "CUSTOMREQUEST")) return CURLOPT_CUSTOMREQUEST;
             break;
         case 'D':
@@ -723,12 +891,15 @@ constant(const char *name)
             if (strEQ(name, "DEBUGFUNCTION")) return CURLOPT_DEBUGFUNCTION;
             if (strEQ(name, "DEFAULT_PROTOCOL")) return CURLOPT_DEFAULT_PROTOCOL;
             if (strEQ(name, "DIRLISTONLY")) return CURLOPT_DIRLISTONLY;
+            if (strEQ(name, "DISALLOW_USERNAME_IN_URL")) return CURLOPT_DISALLOW_USERNAME_IN_URL;
             if (strEQ(name, "DNS_CACHE_TIMEOUT")) return CURLOPT_DNS_CACHE_TIMEOUT;
             if (strEQ(name, "DNS_INTERFACE")) return CURLOPT_DNS_INTERFACE;
             if (strEQ(name, "DNS_LOCAL_IP4")) return CURLOPT_DNS_LOCAL_IP4;
             if (strEQ(name, "DNS_LOCAL_IP6")) return CURLOPT_DNS_LOCAL_IP6;
             if (strEQ(name, "DNS_SERVERS")) return CURLOPT_DNS_SERVERS;
+            if (strEQ(name, "DNS_SHUFFLE_ADDRESSES")) return CURLOPT_DNS_SHUFFLE_ADDRESSES;
             if (strEQ(name, "DNS_USE_GLOBAL_CACHE")) return CURLOPT_DNS_USE_GLOBAL_CACHE;
+            if (strEQ(name, "DOH_URL")) return CURLOPT_DOH_URL;
             break;
         case 'E':
             if (strEQ(name, "EGDSOCKET")) return CURLOPT_EGDSOCKET;
@@ -765,10 +936,13 @@ constant(const char *name)
             if (strEQ(name, "GSSAPI_DELEGATION")) return CURLOPT_GSSAPI_DELEGATION;
             break;
         case 'H':
+            if (strEQ(name, "HAPPY_EYEBALLS_TIMEOUT_MS")) return CURLOPT_HAPPY_EYEBALLS_TIMEOUT_MS;
+            if (strEQ(name, "HAPROXYPROTOCOL")) return CURLOPT_HAPROXYPROTOCOL;
             if (strEQ(name, "HEADER")) return CURLOPT_HEADER;
             if (strEQ(name, "HEADERDATA")) return CURLOPT_HEADERDATA;
             if (strEQ(name, "HEADERFUNCTION")) return CURLOPT_HEADERFUNCTION;
             if (strEQ(name, "HEADEROPT")) return CURLOPT_HEADEROPT;
+            if (strEQ(name, "HTTP09_ALLOWED")) return CURLOPT_HTTP09_ALLOWED;
             if (strEQ(name, "HTTP200ALIASES")) return CURLOPT_HTTP200ALIASES;
             if (strEQ(name, "HTTPAUTH")) return CURLOPT_HTTPAUTH;
             if (strEQ(name, "HTTPGET")) return CURLOPT_HTTPGET;
@@ -810,12 +984,14 @@ constant(const char *name)
             if (strEQ(name, "MAIL_AUTH")) return CURLOPT_MAIL_AUTH;
             if (strEQ(name, "MAIL_FROM")) return CURLOPT_MAIL_FROM;
             if (strEQ(name, "MAIL_RCPT")) return CURLOPT_MAIL_RCPT;
+            if (strEQ(name, "MAXAGE_CONN")) return CURLOPT_MAXAGE_CONN;
             if (strEQ(name, "MAXCONNECTS")) return CURLOPT_MAXCONNECTS;
             if (strEQ(name, "MAXFILESIZE")) return CURLOPT_MAXFILESIZE;
             if (strEQ(name, "MAXFILESIZE_LARGE")) return CURLOPT_MAXFILESIZE_LARGE;
             if (strEQ(name, "MAXREDIRS")) return CURLOPT_MAXREDIRS;
             if (strEQ(name, "MAX_RECV_SPEED_LARGE")) return CURLOPT_MAX_RECV_SPEED_LARGE;
             if (strEQ(name, "MAX_SEND_SPEED_LARGE")) return CURLOPT_MAX_SEND_SPEED_LARGE;
+            if (strEQ(name, "MIMEPOST")) return CURLOPT_MIMEPOST;
             break;
         case 'N':
             if (strEQ(name, "NETRC")) return CURLOPT_NETRC;
@@ -873,6 +1049,7 @@ constant(const char *name)
             if (strEQ(name, "PROXY_SSL_OPTIONS")) return CURLOPT_PROXY_SSL_OPTIONS;
             if (strEQ(name, "PROXY_SSL_VERIFYHOST")) return CURLOPT_PROXY_SSL_VERIFYHOST;
             if (strEQ(name, "PROXY_SSL_VERIFYPEER")) return CURLOPT_PROXY_SSL_VERIFYPEER;
+            if (strEQ(name, "PROXY_TLS13_CIPHERS")) return CURLOPT_PROXY_TLS13_CIPHERS;
             if (strEQ(name, "PROXY_TLSAUTH_PASSWORD")) return CURLOPT_PROXY_TLSAUTH_PASSWORD;
             if (strEQ(name, "PROXY_TLSAUTH_TYPE")) return CURLOPT_PROXY_TLSAUTH_TYPE;
             if (strEQ(name, "PROXY_TLSAUTH_USERNAME")) return CURLOPT_PROXY_TLSAUTH_USERNAME;
@@ -891,6 +1068,8 @@ constant(const char *name)
             if (strEQ(name, "REFERER")) return CURLOPT_REFERER;
             if (strEQ(name, "REQUEST_TARGET")) return CURLOPT_REQUEST_TARGET;
             if (strEQ(name, "RESOLVE")) return CURLOPT_RESOLVE;
+            if (strEQ(name, "RESOLVER_START_DATA")) return CURLOPT_RESOLVER_START_DATA;
+            if (strEQ(name, "RESOLVER_START_FUNCTION")) return CURLOPT_RESOLVER_START_FUNCTION;
             if (strEQ(name, "RESUME_FROM")) return CURLOPT_RESUME_FROM;
             if (strEQ(name, "RESUME_FROM_LARGE")) return CURLOPT_RESUME_FROM_LARGE;
             if (strEQ(name, "RTSPHEADER")) return CURLOPT_RTSPHEADER;
@@ -902,6 +1081,7 @@ constant(const char *name)
             if (strEQ(name, "RTSP_TRANSPORT")) return CURLOPT_RTSP_TRANSPORT;
             break;
         case 'S':
+            if (strEQ(name, "SASL_AUTHZID")) return CURLOPT_SASL_AUTHZID;
             if (strEQ(name, "SASL_IR")) return CURLOPT_SASL_IR;
             if (strEQ(name, "SEEKDATA")) return CURLOPT_SEEKDATA;
             if (strEQ(name, "SEEKFUNCTION")) return CURLOPT_SEEKFUNCTION;
@@ -914,6 +1094,7 @@ constant(const char *name)
             if (strEQ(name, "SOCKS5_GSSAPI_NEC")) return CURLOPT_SOCKS5_GSSAPI_NEC;
             if (strEQ(name, "SOCKS5_GSSAPI_SERVICE")) return CURLOPT_SOCKS5_GSSAPI_SERVICE;
             if (strEQ(name, "SSH_AUTH_TYPES")) return CURLOPT_SSH_AUTH_TYPES;
+            if (strEQ(name, "SSH_COMPRESSION")) return CURLOPT_SSH_COMPRESSION;
             if (strEQ(name, "SSH_HOST_PUBLIC_KEY_MD5")) return CURLOPT_SSH_HOST_PUBLIC_KEY_MD5;
             if (strEQ(name, "SSH_KEYDATA")) return CURLOPT_SSH_KEYDATA;
             if (strEQ(name, "SSH_KEYFUNCTION")) return CURLOPT_SSH_KEYFUNCTION;
@@ -959,16 +1140,22 @@ constant(const char *name)
             if (strEQ(name, "TIMEOUT")) return CURLOPT_TIMEOUT;
             if (strEQ(name, "TIMEOUT_MS")) return CURLOPT_TIMEOUT_MS;
             if (strEQ(name, "TIMEVALUE")) return CURLOPT_TIMEVALUE;
+            if (strEQ(name, "TIMEVALUE_LARGE")) return CURLOPT_TIMEVALUE_LARGE;
+            if (strEQ(name, "TLS13_CIPHERS")) return CURLOPT_TLS13_CIPHERS;
             if (strEQ(name, "TLSAUTH_PASSWORD")) return CURLOPT_TLSAUTH_PASSWORD;
             if (strEQ(name, "TLSAUTH_TYPE")) return CURLOPT_TLSAUTH_TYPE;
             if (strEQ(name, "TLSAUTH_USERNAME")) return CURLOPT_TLSAUTH_USERNAME;
+            if (strEQ(name, "TRAILERDATA")) return CURLOPT_TRAILERDATA;
+            if (strEQ(name, "TRAILERFUNCTION")) return CURLOPT_TRAILERFUNCTION;
             if (strEQ(name, "TRANSFERTEXT")) return CURLOPT_TRANSFERTEXT;
             if (strEQ(name, "TRANSFER_ENCODING")) return CURLOPT_TRANSFER_ENCODING;
             break;
         case 'U':
             if (strEQ(name, "UNIX_SOCKET_PATH")) return CURLOPT_UNIX_SOCKET_PATH;
             if (strEQ(name, "UNRESTRICTED_AUTH")) return CURLOPT_UNRESTRICTED_AUTH;
+            if (strEQ(name, "UPKEEP_INTERVAL_MS")) return CURLOPT_UPKEEP_INTERVAL_MS;
             if (strEQ(name, "UPLOAD")) return CURLOPT_UPLOAD;
+            if (strEQ(name, "UPLOAD_BUFFERSIZE")) return CURLOPT_UPLOAD_BUFFERSIZE;
             if (strEQ(name, "URL")) return CURLOPT_URL;
             if (strEQ(name, "USERAGENT")) return CURLOPT_USERAGENT;
             if (strEQ(name, "USERNAME")) return CURLOPT_USERNAME;
@@ -1025,6 +1212,7 @@ constant(const char *name)
         case 'Q':
         case 'R':
         case 'S':
+            if (strEQ(name, "SLISTPOINT")) return CURLOPTTYPE_SLISTPOINT;
             if (strEQ(name, "STRINGPOINT")) return CURLOPTTYPE_STRINGPOINT;
             break;
         case 'T':
@@ -1072,6 +1260,8 @@ constant(const char *name)
         case 'P':
         case 'Q':
         case 'R':
+            if (strEQ(name, "RECURSIVE_API_CALL")) return CURLM_RECURSIVE_API_CALL;
+            break;
         case 'S':
         case 'T':
         case 'U':
@@ -1186,6 +1376,9 @@ constant(const char *name)
             if (strEQ(name, "DSS")) return CURLKHTYPE_DSS;
             break;
         case 'E':
+            if (strEQ(name, "ECDSA")) return CURLKHTYPE_ECDSA;
+            if (strEQ(name, "ED25519")) return CURLKHTYPE_ED25519;
+            break;
         case 'F':
         case 'G':
         case 'H':
@@ -1376,12 +1569,14 @@ constant(const char *name)
         case 'A':
             if (strEQ(name, "ACTIVESOCKET")) return CURLINFO_ACTIVESOCKET;
             if (strEQ(name, "APPCONNECT_TIME")) return CURLINFO_APPCONNECT_TIME;
+            if (strEQ(name, "APPCONNECT_TIME_T")) return CURLINFO_APPCONNECT_TIME_T;
             break;
         case 'B':
         case 'C':
             if (strEQ(name, "CERTINFO")) return CURLINFO_CERTINFO;
             if (strEQ(name, "CONDITION_UNMET")) return CURLINFO_CONDITION_UNMET;
             if (strEQ(name, "CONNECT_TIME")) return CURLINFO_CONNECT_TIME;
+            if (strEQ(name, "CONNECT_TIME_T")) return CURLINFO_CONNECT_TIME_T;
             if (strEQ(name, "CONTENT_LENGTH_DOWNLOAD")) return CURLINFO_CONTENT_LENGTH_DOWNLOAD;
             if (strEQ(name, "CONTENT_LENGTH_DOWNLOAD_T")) return CURLINFO_CONTENT_LENGTH_DOWNLOAD_T;
             if (strEQ(name, "CONTENT_LENGTH_UPLOAD")) return CURLINFO_CONTENT_LENGTH_UPLOAD;
@@ -1400,6 +1595,7 @@ constant(const char *name)
             break;
         case 'F':
             if (strEQ(name, "FILETIME")) return CURLINFO_FILETIME;
+            if (strEQ(name, "FILETIME_T")) return CURLINFO_FILETIME_T;
             if (strEQ(name, "FTP_ENTRY_PATH")) return CURLINFO_FTP_ENTRY_PATH;
             break;
         case 'G':
@@ -1427,6 +1623,7 @@ constant(const char *name)
             break;
         case 'N':
             if (strEQ(name, "NAMELOOKUP_TIME")) return CURLINFO_NAMELOOKUP_TIME;
+            if (strEQ(name, "NAMELOOKUP_TIME_T")) return CURLINFO_NAMELOOKUP_TIME_T;
             if (strEQ(name, "NONE")) return CURLINFO_NONE;
             if (strEQ(name, "NUM_CONNECTS")) return CURLINFO_NUM_CONNECTS;
             break;
@@ -1436,6 +1633,7 @@ constant(const char *name)
             break;
         case 'P':
             if (strEQ(name, "PRETRANSFER_TIME")) return CURLINFO_PRETRANSFER_TIME;
+            if (strEQ(name, "PRETRANSFER_TIME_T")) return CURLINFO_PRETRANSFER_TIME_T;
             if (strEQ(name, "PRIMARY_IP")) return CURLINFO_PRIMARY_IP;
             if (strEQ(name, "PRIMARY_PORT")) return CURLINFO_PRIMARY_PORT;
             if (strEQ(name, "PRIVATE")) return CURLINFO_PRIVATE;
@@ -1448,9 +1646,11 @@ constant(const char *name)
         case 'R':
             if (strEQ(name, "REDIRECT_COUNT")) return CURLINFO_REDIRECT_COUNT;
             if (strEQ(name, "REDIRECT_TIME")) return CURLINFO_REDIRECT_TIME;
+            if (strEQ(name, "REDIRECT_TIME_T")) return CURLINFO_REDIRECT_TIME_T;
             if (strEQ(name, "REDIRECT_URL")) return CURLINFO_REDIRECT_URL;
             if (strEQ(name, "REQUEST_SIZE")) return CURLINFO_REQUEST_SIZE;
             if (strEQ(name, "RESPONSE_CODE")) return CURLINFO_RESPONSE_CODE;
+            if (strEQ(name, "RETRY_AFTER")) return CURLINFO_RETRY_AFTER;
             if (strEQ(name, "RTSP_CLIENT_CSEQ")) return CURLINFO_RTSP_CLIENT_CSEQ;
             if (strEQ(name, "RTSP_CSEQ_RECV")) return CURLINFO_RTSP_CSEQ_RECV;
             if (strEQ(name, "RTSP_SERVER_CSEQ")) return CURLINFO_RTSP_SERVER_CSEQ;
@@ -1473,6 +1673,7 @@ constant(const char *name)
             if (strEQ(name, "SSL_ENGINES")) return CURLINFO_SSL_ENGINES;
             if (strEQ(name, "SSL_VERIFYRESULT")) return CURLINFO_SSL_VERIFYRESULT;
             if (strEQ(name, "STARTTRANSFER_TIME")) return CURLINFO_STARTTRANSFER_TIME;
+            if (strEQ(name, "STARTTRANSFER_TIME_T")) return CURLINFO_STARTTRANSFER_TIME_T;
             if (strEQ(name, "STRING")) return CURLINFO_STRING;
             break;
         case 'T':
@@ -1480,6 +1681,7 @@ constant(const char *name)
             if (strEQ(name, "TLS_SESSION")) return CURLINFO_TLS_SESSION;
             if (strEQ(name, "TLS_SSL_PTR")) return CURLINFO_TLS_SSL_PTR;
             if (strEQ(name, "TOTAL_TIME")) return CURLINFO_TOTAL_TIME;
+            if (strEQ(name, "TOTAL_TIME_T")) return CURLINFO_TOTAL_TIME_T;
             if (strEQ(name, "TYPEMASK")) return CURLINFO_TYPEMASK;
             break;
         case 'U':
@@ -1492,6 +1694,41 @@ constant(const char *name)
     };
     }
 
+    if (strncmp(name, "CURLINC_", 8) == 0) {
+        name += 8;
+        switch (*name) {
+        case 'A':
+        case 'B':
+        case 'C':
+            if (strEQ(name, "CURL_H")) return CURLINC_CURL_H;
+            break;
+        case 'D':
+        case 'E':
+        case 'F':
+        case 'G':
+        case 'H':
+        case 'I':
+        case 'J':
+        case 'K':
+        case 'L':
+        case 'M':
+        case 'N':
+        case 'O':
+        case 'P':
+        case 'Q':
+        case 'R':
+        case 'S':
+        case 'T':
+        case 'U':
+        case 'V':
+        case 'W':
+        case 'X':
+        case 'Y':
+        case 'Z':
+            break;
+    };
+    }
+
     if (strncmp(name, "CURLHEADER_", 11) == 0) {
         name += 11;
         switch (*name) {
@@ -1883,6 +2120,7 @@ constant(const char *name)
             if (strEQ(name, "ABORTED_BY_CALLBACK")) return CURLE_ABORTED_BY_CALLBACK;
             if (strEQ(name, "AGAIN")) return CURLE_AGAIN;
             if (strEQ(name, "ALREADY_COMPLETE")) return CURLE_ALREADY_COMPLETE;
+            if (strEQ(name, "AUTH_ERROR")) return CURLE_AUTH_ERROR;
             break;
         case 'B':
             if (strEQ(name, "BAD_CALLING_ORDER")) return CURLE_BAD_CALLING_ORDER;
@@ -1980,6 +2218,7 @@ constant(const char *name)
         case 'R':
             if (strEQ(name, "RANGE_ERROR")) return CURLE_RANGE_ERROR;
             if (strEQ(name, "READ_ERROR")) return CURLE_READ_ERROR;
+            if (strEQ(name, "RECURSIVE_API_CALL")) return CURLE_RECURSIVE_API_CALL;
             if (strEQ(name, "RECV_ERROR")) return CURLE_RECV_ERROR;
             if (strEQ(name, "REMOTE_ACCESS_DENIED")) return CURLE_REMOTE_ACCESS_DENIED;
             if (strEQ(name, "REMOTE_DISK_FULL")) return CURLE_REMOTE_DISK_FULL;
@@ -2093,6 +2332,7 @@ constant(const char *name)
             break;
         case 'B':
             if (strEQ(name, "BASIC")) return CURLAUTH_BASIC;
+            if (strEQ(name, "BEARER")) return CURLAUTH_BEARER;
             break;
         case 'C':
         case 'D':
@@ -2135,6 +2375,47 @@ constant(const char *name)
     };
     }
 
+    if (strncmp(name, "CURLALTSVC_", 11) == 0) {
+        name += 11;
+        switch (*name) {
+        case 'A':
+        case 'B':
+        case 'C':
+        case 'D':
+        case 'E':
+        case 'F':
+        case 'G':
+        case 'H':
+            if (strEQ(name, "H1")) return CURLALTSVC_H1;
+            if (strEQ(name, "H2")) return CURLALTSVC_H2;
+            if (strEQ(name, "H3")) return CURLALTSVC_H3;
+            break;
+        case 'I':
+            if (strEQ(name, "IMMEDIATELY")) return CURLALTSVC_IMMEDIATELY;
+            break;
+        case 'J':
+        case 'K':
+        case 'L':
+        case 'M':
+        case 'N':
+        case 'O':
+        case 'P':
+        case 'Q':
+        case 'R':
+            if (strEQ(name, "READONLYFILE")) return CURLALTSVC_READONLYFILE;
+            break;
+        case 'S':
+        case 'T':
+        case 'U':
+        case 'V':
+        case 'W':
+        case 'X':
+        case 'Y':
+        case 'Z':
+            break;
+    };
+    }
+
     errno = EINVAL;
     return 0;
 }
